@@ -16,11 +16,13 @@ func = divopt.gen_example_func(
 	direction = "maximize"	# 最大化 / 最小化
 )
 
+lim_range = [(0,1) for _ in range(dim_n)]
+
 # 最適化 [divopt]
 res = divopt.optimize(
 	func = func,	# 最適化対象関数
 	dim_n = dim_n,	# 入力の次元数
-	lim_range = [(0,1) for _ in range(dim_n)],	# 各軸の範囲
+	lim_range = lim_range,	# 各軸の範囲
 	fin_judge = ["rep", 500],	# 終了条件 (指定: [mode, value])
 	direction = "maximize"	# 最大化 / 最小化
 )
@@ -33,6 +35,7 @@ flag = divopt.is_optimal(
 	func = func,	# 最適化対象関数
 	x = res,	# 検査したい解
 	delta = 0.02,	# 許容誤差
+	lim_range = lim_range,	# 各軸の範囲
 	direction = "maximize"	# 最大化 / 最小化
 )
 
